==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/gamecontroller/GCDualSenseAdaptiveTriggerStatus.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.gamecontroller;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.corehaptic.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedSIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/ implements ValuedEnum {
    /*<values>*/
    Unknown(-1L),
    FeedbackNoLoad(0L),
    FeedbackLoadApplied(1L),
    WeaponReady(2L),
    WeaponFiring(3L),
    WeaponFired(4L),
    VibrationNotVibrating(5L),
    VibrationIsVibrating(6L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/ valueOf(long n) {
        for (/*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/.class.getName());
    }
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/gamecontroller/GCDualSenseAdaptiveTriggerStatus.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.gamecontroller;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.corehaptic.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 14.5 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedSIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/ implements ValuedEnum {
    /*<values>*/
    Unknown(-1L),
    FeedbackNoLoad(0L),
    FeedbackLoadApplied(1L),
    WeaponReady(2L),
    WeaponFiring(3L),
    WeaponFired(4L),
    VibrationNotVibrating(5L),
    VibrationIsVibrating(6L),
    /**
     * @since Available in iOS 14.5 and later.
     */
    SlopeFeedbackReady(7L),
    /**
     * @since Available in iOS 14.5 and later.
     */
    SlopeFeedbackApplyingLoad(8L),
    /**
     * @since Available in iOS 14.5 and later.
     */
    SlopeFeedbackFinished(9L);
    /*</values>*/

    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<methods>*//*</methods>*/

    private final long n;

    private /*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/ valueOf(long n) {
        for (/*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/GCDualSenseAdaptiveTriggerStatus/*</name>*/.class.getName());
    }
}
